==> flutter_logger-0.0.3.tar.gz: lib/src/logger.dart <==
import 'package:flutter_logger/flutter_logger.dart';

class Log {
  Log(String tag, {bool formatTags: true}) {
    if (formatTags) {
      _tag = tag.padRight(30);
    } else
      _tag = tag;
  }

  String _tag;

  String get tag => '${new DateTime.now().toIso8601String().padRight(26, '0')}||$_tag';

  Log addTag(String tag) => new Log('${this.tag}-$tag', formatTags: false);

  void i(Object message) {
    if (!LoggerOptions.shouldLog) return;
    if (message is List) {
      message.forEach((it) {
        print("I/$tag: $it");
      });
    } else
      print("I/$tag: $message");
  }

  void d(Object message) {
    if (!LoggerOptions.shouldLog) return;
    if (message is List) {
      message.forEach((it) {
        print("D/$tag: $it");
      });
    } else
      print("D/$tag: $message");
  }

  void w(Object message) {
    if (!LoggerOptions.shouldLog) return;
    print("W/$tag: WARNING-------------------------------------------------------------------");
    if (message is List) {
      message.forEach((it) {
        print("W/$tag: $it");
      });
    } else
      print("W/$tag: $message");
    print("W/$tag: ==========================================================================");
  }

  void e(Object message) {
    if (!LoggerOptions.shouldLog) return;
    print("E/$tag: +----------------------------------ERROR---------------------------------+");
    if (message is List) {
      message.forEach((it) {
        print("E/$tag: $it");
      });
    } else
      print("E/$tag: $message");
    print("E/$tag: ==========================================================================");
  }
}

class ToStringHelper {
  int _toStringHelperIndent = 0;

  StringBuffer _result = new StringBuffer();

  ToStringHelper(String className) {
    _result..write(className)..write(' {\n');
    _toStringHelperIndent += 2;
  }

  void add(String field, Object value) {
    if (value != null) {
      _result..write(' ' * _toStringHelperIndent)..write(field)..write('=')..write(value)..write(',\n');
    }
  }

  @override
  String toString() {
    _toStringHelperIndent -= 2;
    _result..write(' ' * _toStringHelperIndent)..write('}');
    final stringResult = _result.toString();
    _result = null;
    return stringResult;
  }
}

==> flutter_logger-0.0.4+1.tar.gz: lib/src/logger.dart <==
import 'package:flutter_logger/flutter_logger.dart';

class Log {
  final int tagLength;

  Log(String tag, {this.tagLength = 35}) {
    _tag = tag.padRight(tagLength).substring(0, tagLength);
  }

  String _tag;

  String get tag {
    return '${DateTime.now().toIso8601String().replaceAll('Z', '').padRight(26, '0')}||$_tag';
  }

  Log addTag(String tag) => Log('${this._tag.trim()}-$tag');

  void i(Object message) {
    if (!LoggerOptions.shouldLog) return;
    if (message is List) {
      message.forEach((it) {
        print("I/$tag: $it");
      });
    } else
      print("I/$tag: $message");
  }

  void d(Object message) {
    if (!LoggerOptions.shouldLog) return;
    if (message is List) {
      message.forEach((it) {
        print("D/$tag: $it");
      });
    } else
      print("D/$tag: $message");
  }

  void w(Object message) {
    if (!LoggerOptions.shouldLog) return;
    print("W/$tag: WARNING-------------------------------------------------------------------");
    if (message is List) {
      message.forEach((it) {
        print("W/$tag: $it");
      });
    } else
      print("W/$tag: $message");
    print("W/$tag: ==========================================================================");
  }

  void e(Object message) {
    if (!LoggerOptions.shouldLog) return;
    print("E/$tag: +----------------------------------ERROR---------------------------------+");
    if (message is List) {
      message.forEach((it) {
        print("E/$tag: $it");
      });
    } else
      print("E/$tag: $message");
    print("E/$tag: ==========================================================================");
  }
}

class ToStringHelper {
  int _toStringHelperIndent = 0;

  StringBuffer _result = StringBuffer();

  ToStringHelper(String className) {
    _result..write(className)..write(' {\n');
    _toStringHelperIndent += 2;
  }

  void add(String field, Object value) {
    if (value != null) {
      _result..write(' ' * _toStringHelperIndent)..write(field)..write('=')..write(value)..write(',\n');
    }
  }

  @override
  String toString() {
    _toStringHelperIndent -= 2;
    _result..write(' ' * _toStringHelperIndent)..write('}');
    final stringResult = _result.toString();
    _result = null;
    return stringResult;
  }
}
